#inlineeditor_data {
    width: 200px;
    height: 200px;
}
.inlineeditor {
    cursor: pointer;
    border: 1px solid #ff9;
    display: inline-block;
    min-width: 20px;
    min-height: 20px
}
.inlineeditor:hover{
    background: #ff9;
    color: #444
}
.inlineeditor_top_label{
    float: left;
    background: #444;
    position: fixed;
    padding: 15px 0;
    top: 0;
    left: 0;
    color: #fff;
    font-size: 12px;
    font-family: arial;
    width: 100%;
    z-index: 999;
}
.inlineeditor_top_label label{
    padding: 0 15px;
}
#inlineeditor_dialog {
    background: #fff;
    border: 1px solid #ddd;
    box-shadow: 0 5px 25px rgba(0, 0, 0, 0.2);
    float: left;
    padding: 20px;
    position: fixed;
    z-index: 9999;
    border-radius: 5px;
}
.clear{
    clear:both;
    height:0;
    font-size:0;
    visibility:hidden;
}
#inlineeditor_dialog textarea{
    border: 1px solid #ddd;
    width: 450px;
    height: 100px;
    padding: 10px;
    float: none;
    display: block;
    margin-bottom: 10px;
}
.inlineeditor_btn_block{
    padding-top: 10px;
}
.inlineeditor_btn{
    display: block;
    float: left;
    padding: 0 15px;
    height: 35px;
    line-height: 35px;
    color: #fff;
    border-radius: 3px;
    text-decoration: none;
    margin-right: 10px;
    font-family: arial;
    font-size: 12px;
}
.inlineeditor_btn[href="#save"]{
    background: #5bb75b;
}
.inlineeditor_btn[href="#save"]:hover{
    background: #49ae49;
}
.inlineeditor_btn[href="#cancel"]{
    background: #f84848;
}
.inlineeditor_btn[href="#cancel"]:hover{
    background: #f43838;
}
.inlineeditor_btn:hover{
    text-decoration: none !important;
    color: #fff !important;
}
/*---------------------------------------------------------------------------*/
.editor_switch{
    position: fixed;
    right: 50px;
    bottom: 50px;
    height: 56px;
    width: 56px;
    z-index: 99;
}
.editor_switch button{
    background-color: #60c710;
    height: 56px;
    border-radius: 50%;
    border: none;
    position: relative;
    width: 56px;
    box-shadow: 0 0 4px rgba(0, 0, 0, 0.14), 0 4px 8px rgba(0, 0, 0, 0.28);
    box-sizing: content-box;
    cursor: pointer;
    outline: medium none;
    padding: 0;
    pointer-events: auto;
    position: relative;
    transform: scale(1) rotate(360deg);
    transition: transform 150ms cubic-bezier(0.4, 0, 1, 1) 0s;
}
.editor_switch button.editor_off{
    background-color: #1976d2;
}
.editor_switch button.editor_on{
    background-color: #60c710;
}
.tooltip_editor {
    display: block;
    margin-right: 8px;
    opacity: 0;
    right: 100%;
    transition: opacity 150ms cubic-bezier(0.4, 0, 1, 1) 0s;
    position: absolute;
    top: 17px
}
.tooltip_editor span {
    background: rgba(70, 70, 70, 0.9) none repeat scroll 0 0;
    border-radius: 2px;
    box-shadow: 0 1px 2px rgba(0, 0, 0, 0.15);
    color: #ececec;
    font-weight: bold;
    line-height: 32px;
    padding: 0 8px;
    display: block;
    float: left;
    height: 30px;
    white-space: nowrap
}
.editor_switch button .fa.fa-font,
.editor_switch button .fa.fa-pencil{
    left: 0;
    margin-left: 16px;
    margin-top: 16px;
    position: absolute;
    top: 0;
    transition: all 0.2s cubic-bezier(0.4, 0, 0.2, 1) 0s;
    color: #fff;
    height: 56px;
    line-height: 52px;
    margin: auto;
    text-align: center;
    width: 56px;
    font-size: 20px;
}
.editor_switch button .fa.fa-font{
    opacity: 0;
    transform: rotate(225deg);
    visibility: hidden
}
.editor_switch button .fa.fa-pencil{
    display: block;
}
.editor_switch:hover .tooltip_editor{
    opacity: 1
}
.editor_switch button:hover .fa.fa-pencil,
.editor_switch button.editor_on .fa.fa-pencil{
    opacity: 0;
    transform: rotate(225deg);
}
.editor_switch button:hover .fa.fa-font,
.editor_switch button.editor_on .fa.fa-font{
    opacity: 1;
    visibility: visible;
    transform: rotate(360deg);
}